@@ -1,4 +1,4 @@
-#  Copyright (c) 2023 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
+#  Copyright (c) 2024 Merck & Co., Inc., Rahway, NJ, USA and its affiliates.
 #  All rights reserved.
 #
 #  This file is part of the pkglite program.
@@ -24,3 +24,7 @@ NULL
 
 #' @importFrom Rcpp sourceCpp
 NULL
+
+# For safeguarding code examples and tests
+#' @importFrom rlang is_installed
+NULL
